@@ -1,26 +1,28 @@
 import itertools
+from collections import OrderedDict
+from datetime import datetime
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-from moto.packages.boto.ec2.blockdevicemapping import (
-    BlockDeviceType,
-    BlockDeviceMapping,
-)
-from moto.ec2.exceptions import InvalidInstanceIdError
-
-from collections import OrderedDict
-from moto.core import BaseBackend, BaseModel, CloudFormationModel
-from moto.core.utils import camelcase_to_underscores, BackendDict
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel, CloudFormationModel
+from moto.core.utils import camelcase_to_underscores
 from moto.ec2 import ec2_backends
+from moto.ec2.exceptions import InvalidInstanceIdError
 from moto.ec2.models import EC2Backend
 from moto.ec2.models.instances import Instance
-from moto.elb.models import elb_backends, ELBBackend
-from moto.elbv2.models import elbv2_backends, ELBv2Backend
 from moto.elb.exceptions import LoadBalancerNotFoundError
+from moto.elb.models import ELBBackend, elb_backends
+from moto.elbv2.models import ELBv2Backend, elbv2_backends
 from moto.moto_api._internal import mock_random as random
+from moto.packages.boto.ec2.blockdevicemapping import (
+    BlockDeviceMapping,
+    BlockDeviceType,
+)
+
 from .exceptions import (
     AutoscalingClientError,
-    ResourceContentionError,
     InvalidInstanceError,
+    ResourceContentionError,
     ValidationError,
 )
 
@@ -30,7 +32,11 @@ DEFAULT_COOLDOWN = 300
 ASG_NAME_TAG = "aws:autoscaling:groupName"
 
 
-class InstanceState(object):
+def make_int(value: Union[None, str, int]) -> Optional[int]:
+    return int(value) if value is not None else value
+
+
+class InstanceState:
     def __init__(
         self,
         instance: "Instance",
@@ -174,13 +180,14 @@ class FakeLaunchConfiguration(CloudFormationModel):
     def create_from_instance(
         cls, name: str, instance: Instance, backend: "AutoScalingBackend"
     ) -> "FakeLaunchConfiguration":
+        security_group_names = [sg.name for sg in instance.security_groups]
         config = backend.create_launch_configuration(
             name=name,
             image_id=instance.image_id,
             kernel_id="",
             ramdisk_id="",
             key_name=instance.key_name,
-            security_groups=instance.security_groups,
+            security_groups=security_group_names,
             user_data=instance.user_data,
             instance_type=instance.instance_type,
             instance_monitoring=False,
@@ -315,11 +322,11 @@ class FakeScheduledAction(CloudFormationModel):
         max_size: Optional[int],
         min_size: Optional[int],
         scheduled_action_name: str,
-        start_time: str,
-        end_time: str,
-        recurrence: str,
+        start_time: Optional[str],
+        end_time: Optional[str],
+        recurrence: Optional[str],
+        timezone: Optional[str],
     ):
-
         self.name = name
         self.desired_capacity = desired_capacity
         self.max_size = max_size
@@ -328,6 +335,7 @@ class FakeScheduledAction(CloudFormationModel):
         self.end_time = end_time
         self.recurrence = recurrence
         self.scheduled_action_name = scheduled_action_name
+        self.timezone = timezone
 
     @staticmethod
     def cloudformation_name_type() -> str:
@@ -347,7 +355,6 @@ class FakeScheduledAction(CloudFormationModel):
         region_name: str,
         **kwargs: Any,
     ) -> "FakeScheduledAction":
-
         properties = cloudformation_json["Properties"]
 
         backend = autoscaling_backends[account_id][region_name]
@@ -367,12 +374,26 @@ class FakeScheduledAction(CloudFormationModel):
             start_time=properties.get("StartTime"),
             end_time=properties.get("EndTime"),
             recurrence=properties.get("Recurrence"),
+            timezone=properties.get("TimeZone"),
         )
         return scheduled_action
 
 
+class FailedScheduledUpdateGroupActionRequest:
+    def __init__(
+        self,
+        *,
+        scheduled_action_name: str,
+        error_code: Optional[str] = None,
+        error_message: Optional[str] = None,
+    ) -> None:
+        self.scheduled_action_name = scheduled_action_name
+        self.error_code = error_code
+        self.error_message = error_message
+
+
 def set_string_propagate_at_launch_booleans_on_tags(
-    tags: List[Dict[str, Any]]
+    tags: List[Dict[str, Any]],
 ) -> List[Dict[str, Any]]:
     bool_to_string = {True: "true", False: "false"}
     for tag in tags:
@@ -381,6 +402,20 @@ def set_string_propagate_at_launch_booleans_on_tags(
     return tags
 
 
+class FakeWarmPool(CloudFormationModel):
+    def __init__(
+        self,
+        max_capacity: Optional[int],
+        min_size: Optional[int],
+        pool_state: Optional[str],
+        instance_reuse_policy: Optional[Dict[str, bool]],
+    ):
+        self.max_capacity = max_capacity
+        self.min_size = min_size or 0
+        self.pool_state = pool_state or "Stopped"
+        self.instance_reuse_policy = instance_reuse_policy
+
+
 class FakeAutoScalingGroup(CloudFormationModel):
     def __init__(
         self,
@@ -391,20 +426,21 @@ class FakeAutoScalingGroup(CloudFormationModel):
         min_size: Optional[int],
         launch_config_name: str,
         launch_template: Dict[str, Any],
-        vpc_zone_identifier: str,
+        vpc_zone_identifier: Optional[str],
         default_cooldown: Optional[int],
         health_check_period: Optional[int],
         health_check_type: Optional[str],
         load_balancers: List[str],
         target_group_arns: List[str],
-        placement_group: str,
-        termination_policies: str,
+        placement_group: Optional[str],
+        termination_policies: List[str],
         autoscaling_backend: "AutoScalingBackend",
         ec2_backend: EC2Backend,
         tags: List[Dict[str, str]],
-        mixed_instance_policy: Optional[Dict[str, Any]],
+        mixed_instances_policy: Optional[Dict[str, Any]],
         capacity_rebalance: bool,
         new_instances_protected_from_scale_in: bool = False,
+        created_time: datetime = datetime.now(),
     ):
         self.autoscaling_backend = autoscaling_backend
         self.ec2_backend = ec2_backend
@@ -424,9 +460,9 @@ class FakeAutoScalingGroup(CloudFormationModel):
         self.launch_config = None
 
         self._set_launch_configuration(
-            launch_config_name, launch_template, mixed_instance_policy
+            launch_config_name, launch_template, mixed_instances_policy
         )
-        self.mixed_instance_policy = mixed_instance_policy
+        self.mixed_instances_policy = mixed_instances_policy
 
         self.default_cooldown = (
             default_cooldown if default_cooldown else DEFAULT_COOLDOWN
@@ -448,6 +484,8 @@ class FakeAutoScalingGroup(CloudFormationModel):
         self.set_desired_capacity(desired_capacity)
 
         self.metrics: List[str] = []
+        self.warm_pool: Optional[FakeWarmPool] = None
+        self.created_time = created_time
 
     @property
     def tags(self) -> List[Dict[str, str]]:
@@ -456,10 +494,10 @@ class FakeAutoScalingGroup(CloudFormationModel):
     @tags.setter
     def tags(self, tags: List[Dict[str, str]]) -> None:
         for tag in tags:
-            if "resource_id" not in tag or not tag["resource_id"]:
-                tag["resource_id"] = self.name
-            if "resource_type" not in tag or not tag["resource_type"]:
-                tag["resource_type"] = "auto-scaling-group"
+            if "ResourceId" not in tag or not tag["ResourceId"]:
+                tag["ResourceId"] = self.name
+            if "ResourceType" not in tag or not tag["ResourceType"]:
+                tag["ResourceType"] = "auto-scaling-group"
         self._tags = tags
 
     @property
@@ -483,7 +521,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
         if vpc_zone_identifier:
             # extract azs for vpcs
             subnet_ids = vpc_zone_identifier.split(",")
-            subnets = self.autoscaling_backend.ec2_backend.get_all_subnets(
+            subnets = self.autoscaling_backend.ec2_backend.describe_subnets(
                 subnet_ids=subnet_ids
             )
             vpc_zones = [subnet.availability_zone for subnet in subnets]
@@ -509,7 +547,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
         self,
         launch_config_name: str,
         launch_template: Dict[str, Any],
-        mixed_instance_policy: Optional[Dict[str, Any]],
+        mixed_instances_policy: Optional[Dict[str, Any]],
     ) -> None:
         if launch_config_name:
             self.launch_config = self.autoscaling_backend.launch_configurations[
@@ -517,15 +555,19 @@ class FakeAutoScalingGroup(CloudFormationModel):
             ]
             self.launch_config_name = launch_config_name
 
-        if launch_template or mixed_instance_policy:
+        if launch_template or mixed_instances_policy:
             if launch_template:
                 launch_template_id = launch_template.get("launch_template_id")
                 launch_template_name = launch_template.get("launch_template_name")
+                # If no version is specified, AWS will use '$Default'
+                # However, AWS will never show the version if it is not specified
+                # (If the user explicitly specifies '$Default', it will be returned)
                 self.launch_template_version = (
                     launch_template.get("version") or "$Default"
                 )
-            elif mixed_instance_policy:
-                spec = mixed_instance_policy["LaunchTemplate"][
+                self.provided_launch_template_version = launch_template.get("version")
+            elif mixed_instances_policy:
+                spec = mixed_instances_policy["LaunchTemplate"][
                     "LaunchTemplateSpecification"
                 ]
                 launch_template_id = spec.get("LaunchTemplateId")
@@ -575,6 +617,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
         }
         load_balancer_names = properties.get("LoadBalancerNames", [])
         target_group_arns = properties.get("TargetGroupARNs", [])
+        mixed_instances_policy = properties.get("MixedInstancesPolicy", {})
 
         backend = autoscaling_backends[account_id][region_name]
         group = backend.create_auto_scaling_group(
@@ -601,6 +644,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
             new_instances_protected_from_scale_in=properties.get(
                 "NewInstancesProtectedFromScaleIn", False
             ),
+            mixed_instances_policy=mixed_instances_policy,
         )
         return group
 
@@ -701,7 +745,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
                 desired_capacity = max_size
 
         self._set_launch_configuration(
-            launch_config_name, launch_template, mixed_instance_policy=None
+            launch_config_name, launch_template, mixed_instances_policy=None
         )
 
         if health_check_period is not None:
@@ -781,7 +825,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
             if self.launch_config
             else None
         )
-        reservation = self.autoscaling_backend.ec2_backend.add_instances(
+        reservation = self.autoscaling_backend.ec2_backend.run_instances(
             self.image_id,
             count_needed,
             self.user_data,
@@ -810,6 +854,23 @@ class FakeAutoScalingGroup(CloudFormationModel):
     def enable_metrics_collection(self, metrics: List[str]) -> None:
         self.metrics = metrics or []
 
+    def put_warm_pool(
+        self,
+        max_capacity: Optional[int],
+        min_size: Optional[int],
+        pool_state: Optional[str],
+        instance_reuse_policy: Optional[Dict[str, bool]],
+    ) -> None:
+        self.warm_pool = FakeWarmPool(
+            max_capacity=max_capacity,
+            min_size=min_size,
+            pool_state=pool_state,
+            instance_reuse_policy=instance_reuse_policy,
+        )
+
+    def get_warm_pool(self) -> Optional[FakeWarmPool]:
+        return self.warm_pool
+
 
 class AutoScalingBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
@@ -823,15 +884,6 @@ class AutoScalingBackend(BaseBackend):
         self.elb_backend: ELBBackend = elb_backends[self.account_id][region_name]
         self.elbv2_backend: ELBv2Backend = elbv2_backends[self.account_id][region_name]
 
-    @staticmethod
-    def default_vpc_endpoint_service(service_region: str, zones: List[Dict[str, Any]]) -> List[Dict[str, Any]]:  # type: ignore[misc]
-        """Default VPC endpoint service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "autoscaling"
-        ) + BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "autoscaling-plans"
-        )
-
     def create_launch_configuration(
         self,
         name: str,
@@ -904,9 +956,6 @@ class AutoScalingBackend(BaseBackend):
     def delete_launch_configuration(self, launch_configuration_name: str) -> None:
         self.launch_configurations.pop(launch_configuration_name, None)
 
-    def make_int(self, value: Union[None, str, int]) -> Optional[int]:
-        return int(value) if value is not None else value
-
     def put_scheduled_update_group_action(
         self,
         name: str,
@@ -914,13 +963,14 @@ class AutoScalingBackend(BaseBackend):
         max_size: Union[None, str, int],
         min_size: Union[None, str, int],
         scheduled_action_name: str,
-        start_time: str,
-        end_time: str,
-        recurrence: str,
+        start_time: Optional[str],
+        end_time: Optional[str],
+        recurrence: Optional[str],
+        timezone: Optional[str],
     ) -> FakeScheduledAction:
-        max_size = self.make_int(max_size)
-        min_size = self.make_int(min_size)
-        desired_capacity = self.make_int(desired_capacity)
+        max_size = make_int(max_size)
+        min_size = make_int(min_size)
+        desired_capacity = make_int(desired_capacity)
 
         scheduled_action = FakeScheduledAction(
             name=name,
@@ -931,11 +981,39 @@ class AutoScalingBackend(BaseBackend):
             start_time=start_time,
             end_time=end_time,
             recurrence=recurrence,
+            timezone=timezone,
         )
 
         self.scheduled_actions[scheduled_action_name] = scheduled_action
         return scheduled_action
 
+    def batch_put_scheduled_update_group_action(
+        self, name: str, actions: List[Dict[str, Any]]
+    ) -> List[FailedScheduledUpdateGroupActionRequest]:
+        result = []
+        for action in actions:
+            try:
+                self.put_scheduled_update_group_action(
+                    name=name,
+                    desired_capacity=action.get("DesiredCapacity"),
+                    max_size=action.get("MaxSize"),
+                    min_size=action.get("MinSize"),
+                    scheduled_action_name=action["ScheduledActionName"],
+                    start_time=action.get("StartTime"),
+                    end_time=action.get("EndTime"),
+                    recurrence=action.get("Recurrence"),
+                    timezone=action.get("TimeZone"),
+                )
+            except AutoscalingClientError as err:
+                result.append(
+                    FailedScheduledUpdateGroupActionRequest(
+                        scheduled_action_name=action["ScheduledActionName"],
+                        error_code=err.error_type,
+                        error_message=err.message,
+                    )
+                )
+        return result
+
     def describe_scheduled_actions(
         self,
         autoscaling_group_name: Optional[str] = None,
@@ -963,6 +1041,27 @@ class AutoScalingBackend(BaseBackend):
         )
         if scheduled_action:
             self.scheduled_actions.pop(scheduled_action_name, None)
+        else:
+            raise ValidationError("Scheduled action name not found")
+
+    def batch_delete_scheduled_action(
+        self, auto_scaling_group_name: str, scheduled_action_names: List[str]
+    ) -> List[FailedScheduledUpdateGroupActionRequest]:
+        result = []
+        for scheduled_action_name in scheduled_action_names:
+            try:
+                self.delete_scheduled_action(
+                    auto_scaling_group_name, scheduled_action_name
+                )
+            except AutoscalingClientError as err:
+                result.append(
+                    FailedScheduledUpdateGroupActionRequest(
+                        scheduled_action_name=scheduled_action_name,
+                        error_code=err.error_type,
+                        error_message=err.message,
+                    )
+                )
+        return result
 
     def create_auto_scaling_group(
         self,
@@ -973,31 +1072,31 @@ class AutoScalingBackend(BaseBackend):
         min_size: Union[None, str, int],
         launch_config_name: str,
         launch_template: Dict[str, Any],
-        vpc_zone_identifier: str,
+        vpc_zone_identifier: Optional[str],
         default_cooldown: Optional[int],
         health_check_period: Union[None, str, int],
         health_check_type: Optional[str],
         load_balancers: List[str],
         target_group_arns: List[str],
-        placement_group: str,
-        termination_policies: str,
+        placement_group: Optional[str],
+        termination_policies: List[str],
         tags: List[Dict[str, str]],
         capacity_rebalance: bool = False,
         new_instances_protected_from_scale_in: bool = False,
         instance_id: Optional[str] = None,
-        mixed_instance_policy: Optional[Dict[str, Any]] = None,
+        mixed_instances_policy: Optional[Dict[str, Any]] = None,
     ) -> FakeAutoScalingGroup:
-        max_size = self.make_int(max_size)
-        min_size = self.make_int(min_size)
-        desired_capacity = self.make_int(desired_capacity)
-        default_cooldown = self.make_int(default_cooldown)
+        max_size = make_int(max_size)
+        min_size = make_int(min_size)
+        desired_capacity = make_int(desired_capacity)
+        default_cooldown = make_int(default_cooldown)
 
         # Verify only a single launch config-like parameter is provided.
         params = [
             launch_config_name,
             launch_template,
             instance_id,
-            mixed_instance_policy,
+            mixed_instances_policy,
         ]
         num_params = sum([1 for param in params if param])
 
@@ -1027,9 +1126,7 @@ class AutoScalingBackend(BaseBackend):
             launch_template=launch_template,
             vpc_zone_identifier=vpc_zone_identifier,
             default_cooldown=default_cooldown,
-            health_check_period=self.make_int(health_check_period)
-            if health_check_period
-            else 300,
+            health_check_period=make_int(health_check_period or 300),
             health_check_type=health_check_type,
             load_balancers=load_balancers,
             target_group_arns=target_group_arns,
@@ -1039,7 +1136,7 @@ class AutoScalingBackend(BaseBackend):
             ec2_backend=self.ec2_backend,
             tags=tags,
             new_instances_protected_from_scale_in=new_instances_protected_from_scale_in,
-            mixed_instance_policy=mixed_instance_policy,
+            mixed_instances_policy=mixed_instances_policy,
             capacity_rebalance=capacity_rebalance,
         )
 
@@ -1089,13 +1186,39 @@ class AutoScalingBackend(BaseBackend):
         return group
 
     def describe_auto_scaling_groups(
-        self, names: List[str]
+        self, names: List[str], filters: Optional[List[Dict[str, str]]] = None
     ) -> List[FakeAutoScalingGroup]:
-        groups = self.autoscaling_groups.values()
+        groups = list(self.autoscaling_groups.values())
+
+        if filters:
+            for f in filters:
+                if f["Name"] == "tag-key":
+                    groups = [
+                        group
+                        for group in groups
+                        if any(tag["Key"] in f["Values"] for tag in group.tags)
+                    ]
+                elif f["Name"] == "tag-value":
+                    groups = [
+                        group
+                        for group in groups
+                        if any(tag["Value"] in f["Values"] for tag in group.tags)
+                    ]
+                elif f["Name"].startswith("tag:"):
+                    tag_key = f["Name"][4:]
+                    groups = [
+                        group
+                        for group in groups
+                        if any(
+                            tag["Key"] == tag_key and tag["Value"] in f["Values"]
+                            for tag in group.tags
+                        )
+                    ]
+
         if names:
-            return [group for group in groups if group.name in names]
-        else:
-            return list(groups)
+            groups = [group for group in groups if group.name in names]
+
+        return groups
 
     def delete_auto_scaling_group(self, group_name: str) -> None:
         self.set_desired_capacity(group_name, 0)
@@ -1219,11 +1342,11 @@ class AutoScalingBackend(BaseBackend):
     ) -> FakeLifeCycleHook:
         lifecycle_hook = FakeLifeCycleHook(name, as_name, transition, timeout, result)
 
-        self.lifecycle_hooks["%s_%s" % (as_name, name)] = lifecycle_hook
+        self.lifecycle_hooks[f"{as_name}_{name}"] = lifecycle_hook
         return lifecycle_hook
 
     def describe_lifecycle_hooks(
-        self, as_name: str, lifecycle_hook_names: Optional[str] = None
+        self, as_name: str, lifecycle_hook_names: Optional[List[str]] = None
     ) -> List[FakeLifeCycleHook]:
         return [
             lifecycle_hook
@@ -1235,7 +1358,7 @@ class AutoScalingBackend(BaseBackend):
         ]
 
     def delete_lifecycle_hook(self, as_name: str, name: str) -> None:
-        self.lifecycle_hooks.pop("%s_%s" % (as_name, name), None)
+        self.lifecycle_hooks.pop(f"{as_name}_{name}", None)
 
     def put_scaling_policy(
         self,
@@ -1339,31 +1462,31 @@ class AutoScalingBackend(BaseBackend):
 
     def create_or_update_tags(self, tags: List[Dict[str, str]]) -> None:
         for tag in tags:
-            group_name = tag["resource_id"]
+            group_name = tag["ResourceId"]
             group = self.autoscaling_groups[group_name]
             old_tags = group.tags
 
             new_tags = []
             # if key was in old_tags, update old tag
             for old_tag in old_tags:
-                if old_tag["key"] == tag["key"]:
+                if old_tag["Key"] == tag["Key"]:
                     new_tags.append(tag)
                 else:
                     new_tags.append(old_tag)
 
             # if key was never in old_tag's add it (create tag)
-            if not any(new_tag["key"] == tag["key"] for new_tag in new_tags):
+            if not any(new_tag["Key"] == tag["Key"] for new_tag in new_tags):
                 new_tags.append(tag)
 
             group.tags = new_tags
 
     def delete_tags(self, tags: List[Dict[str, str]]) -> None:
         for tag_to_delete in tags:
-            group_name = tag_to_delete["resource_id"]
-            key_to_delete = tag_to_delete["key"]
+            group_name = tag_to_delete["ResourceId"]
+            key_to_delete = tag_to_delete["Key"]
             group = self.autoscaling_groups[group_name]
             old_tags = group.tags
-            group.tags = [x for x in old_tags if x["key"] != key_to_delete]
+            group.tags = [x for x in old_tags if x["Key"] != key_to_delete]
 
     def attach_load_balancers(
         self, group_name: str, load_balancer_names: List[str]
@@ -1521,25 +1644,53 @@ class AutoScalingBackend(BaseBackend):
     def describe_tags(self, filters: List[Dict[str, str]]) -> List[Dict[str, str]]:
         """
         Pagination is not yet implemented.
-        Only the `auto-scaling-group` and `propagate-at-launch` filters are implemented.
         """
         resources = self.autoscaling_groups.values()
         tags = list(itertools.chain(*[r.tags for r in resources]))
         for f in filters:
             if f["Name"] == "auto-scaling-group":
-                tags = [t for t in tags if t["resource_id"] in f["Values"]]
+                tags = [t for t in tags if t["ResourceId"] in f["Values"]]
             if f["Name"] == "propagate-at-launch":
                 values = [v.lower() for v in f["Values"]]
                 tags = [
-                    t
-                    for t in tags
-                    if t.get("propagate_at_launch", "").lower() in values
+                    t for t in tags if t.get("PropagateAtLaunch", "").lower() in values
                 ]
+            if f["Name"] == "key":
+                tags = [t for t in tags if t["Key"] in f["Values"]]
+            if f["Name"] == "value":
+                tags = [t for t in tags if t["Value"] in f["Values"]]
         return tags
 
     def enable_metrics_collection(self, group_name: str, metrics: List[str]) -> None:
         group = self.describe_auto_scaling_groups([group_name])[0]
         group.enable_metrics_collection(metrics)
 
+    def put_warm_pool(
+        self,
+        group_name: str,
+        max_capacity: Optional[int],
+        min_size: Optional[int],
+        pool_state: Optional[str],
+        instance_reuse_policy: Optional[Dict[str, bool]],
+    ) -> None:
+        group = self.describe_auto_scaling_groups([group_name])[0]
+        group.put_warm_pool(
+            max_capacity=max_capacity,
+            min_size=min_size,
+            pool_state=pool_state,
+            instance_reuse_policy=instance_reuse_policy,
+        )
+
+    def describe_warm_pool(self, group_name: str) -> Optional[FakeWarmPool]:
+        """
+        Pagination is not yet implemented. Does not create/return any Instances currently.
+        """
+        group = self.describe_auto_scaling_groups([group_name])[0]
+        return group.get_warm_pool()
+
+    def delete_warm_pool(self, group_name: str) -> None:
+        group = self.describe_auto_scaling_groups([group_name])[0]
+        group.warm_pool = None
+
 
 autoscaling_backends = BackendDict(AutoScalingBackend, "autoscaling")
