@@ -1,6 +1,6 @@
 import importlib
-import sys
-from typing import TYPE_CHECKING, Iterable, Tuple, Union, overload
+import os
+from typing import TYPE_CHECKING, Iterable, Optional, Union, overload
 
 import moto
 
@@ -20,6 +20,8 @@ if TYPE_CHECKING:
     from moto.autoscaling.models import AutoScalingBackend
     from moto.awslambda.models import LambdaBackend
     from moto.batch.models import BatchBackend
+    from moto.bedrock.models import BedrockBackend
+    from moto.bedrockagent.models import AgentsforBedrockBackend
     from moto.budgets.models import BudgetsBackend
     from moto.ce.models import CostExplorerBackend
     from moto.cloudformation.models import CloudFormationBackend
@@ -33,7 +35,7 @@ if TYPE_CHECKING:
     from moto.cognitoidp.models import CognitoIdpBackend
     from moto.comprehend.models import ComprehendBackend
     from moto.config.models import ConfigBackend
-    from moto.core import SERVICE_BACKEND, BackendDict, BaseBackend
+    from moto.core.base_backend import SERVICE_BACKEND, BackendDict
     from moto.databrew.models import DataBrewBackend
     from moto.datapipeline.models import DataPipelineBackend
     from moto.datasync.models import DataSyncBackend
@@ -104,10 +106,12 @@ if TYPE_CHECKING:
     from moto.redshift.models import RedshiftBackend
     from moto.redshiftdata.models import RedshiftDataAPIServiceBackend
     from moto.rekognition.models import RekognitionBackend
+    from moto.resiliencehub.models import ResilienceHubBackend
     from moto.resourcegroups.models import ResourceGroupsBackend
     from moto.resourcegroupstaggingapi.models import ResourceGroupsTaggingAPIBackend
     from moto.robomaker.models import RoboMakerBackend
     from moto.route53.models import Route53Backend
+    from moto.route53domains.models import Route53DomainsBackend
     from moto.route53resolver.models import Route53ResolverBackend
     from moto.s3.models import S3Backend
     from moto.s3control.models import S3ControlBackend
@@ -133,16 +137,37 @@ if TYPE_CHECKING:
     from moto.timestreamwrite.models import TimestreamWriteBackend
     from moto.transcribe.models import TranscribeBackend
     from moto.wafv2.models import WAFV2Backend
+    from moto.workspaces.models import WorkSpacesBackend
     from moto.xray.models import XRayBackend
 
 
-decorators = [d for d in dir(moto) if d.startswith("mock_") and not d == "mock_all"]
-decorator_functions = [getattr(moto, f) for f in decorators]
-BACKENDS = {f.boto3_name: (f.name, f.backend) for f in decorator_functions}
-BACKENDS["dynamodb_v20111205"] = ("dynamodb_v20111205", "dynamodb_backends")
-BACKENDS["moto_api"] = ("moto_api._internal", "moto_api_backends")
-BACKENDS["instance_metadata"] = ("instance_metadata", "instance_metadata_backends")
-BACKENDS["s3bucket_path"] = ("s3", "s3_backends")
+ALT_SERVICE_NAMES = {"lambda": "awslambda", "moto_api": "moto_api._internal"}
+ALT_BACKEND_NAMES = {
+    "moto_api._internal": "moto_api",
+    "awslambda": "lambda",
+    "awslambda_simple": "lambda_simple",
+    "dynamodb_v20111205": "dynamodb",
+    "elasticbeanstalk": "eb",
+}
+
+
+def list_of_moto_modules() -> Iterable[str]:
+    path = os.path.dirname(moto.__file__)
+    for backend in sorted(os.listdir(path)):
+        is_dir = os.path.isdir(os.path.join(path, backend))
+        valid_folder = not backend.startswith("__")
+        if is_dir and valid_folder:
+            yield backend
+
+
+def get_service_from_url(url: str) -> Optional[str]:
+    from moto.backend_index import backend_url_patterns
+
+    for service, pattern in backend_url_patterns:
+        if pattern.match(url):
+            return service
+    return None
+
 
 # There's a similar Union that we could import from boto3-stubs, but it wouldn't have
 # moto's custom service backends
@@ -159,6 +184,8 @@ SERVICE_NAMES = Union[
     "Literal['athena']",
     "Literal['autoscaling']",
     "Literal['batch']",
+    "Literal['bedrock']",
+    "Literal['bedrock-agent']",
     "Literal['budgets']",
     "Literal['ce']",
     "Literal['cloudformation']",
@@ -241,11 +268,13 @@ SERVICE_NAMES = Union[
     "Literal['redshift']",
     "Literal['redshift-data']",
     "Literal['rekognition']",
+    "Literal['resiliencehub']",
     "Literal['resource-groups']",
     "Literal['resourcegroupstaggingapi']",
     "Literal['robomaker']",
     "Literal['route53']",
     "Literal['route53resolver']",
+    "Literal['route53domains']",
     "Literal['s3']",
     "Literal['s3bucket_path']",
     "Literal['s3control']",
@@ -271,6 +300,7 @@ SERVICE_NAMES = Union[
     "Literal['timestream-write']",
     "Literal['transcribe']",
     "Literal['wafv2']",
+    "Literal['workspaces']",
     "Literal['xray']",
 ]
 
@@ -283,36 +313,10 @@ def _import_backend(
     return getattr(module, backends_name)
 
 
-def backends() -> "Iterable[BackendDict[BaseBackend]]":
-    for module_name, backends_name in BACKENDS.values():
-        yield _import_backend(module_name, backends_name)
-
-
-def service_backends() -> "Iterable[BackendDict[BaseBackend]]":
-    services = [(f.name, f.backend) for f in decorator_functions]
-    for module_name, backends_name in sorted(set(services)):
-        yield _import_backend(module_name, backends_name)
-
-
-def loaded_backends() -> "Iterable[Tuple[str, BackendDict[BaseBackend]]]":
-    loaded_modules = sys.modules.keys()
-    moto_modules = [m for m in loaded_modules if m.startswith("moto.")]
-    imported_backends = [
-        name
-        for name, (module_name, _) in BACKENDS.items()
-        if f"moto.{module_name}" in moto_modules
-    ]
-    for name in imported_backends:
-        module_name, backends_name = BACKENDS[name]
-        yield name, _import_backend(module_name, backends_name)
-
-
-# fmt: off
-# This is more or less the dummy-implementation style that's currently in black's preview
-# style. It should be live in black v24.0+, at which point we should remove the # fmt: off
-# directive.
 @overload
-def get_backend(name: "Literal['acm']") -> "BackendDict[AWSCertificateManagerBackend]": ...
+def get_backend(
+    name: "Literal['acm']",
+) -> "BackendDict[AWSCertificateManagerBackend]": ...
 @overload
 def get_backend(name: "Literal['acm-pca']") -> "BackendDict[ACMPCABackend]": ...
 @overload
@@ -320,27 +324,43 @@ def get_backend(name: "Literal['amp']") -> "BackendDict[PrometheusServiceBackend
 @overload
 def get_backend(name: "Literal['apigateway']") -> "BackendDict[APIGatewayBackend]": ...
 @overload
-def get_backend(name: "Literal['apigatewaymanagementapi']") -> "BackendDict[ApiGatewayManagementApiBackend]": ...
+def get_backend(
+    name: "Literal['apigatewaymanagementapi']",
+) -> "BackendDict[ApiGatewayManagementApiBackend]": ...
 @overload
-def get_backend(name: "Literal['apigatewayv2']") -> "BackendDict[ApiGatewayV2Backend]": ...
+def get_backend(
+    name: "Literal['apigatewayv2']",
+) -> "BackendDict[ApiGatewayV2Backend]": ...
 @overload
 def get_backend(name: "Literal['appconfig']") -> "BackendDict[AppConfigBackend]": ...
 @overload
-def get_backend(name: "Literal['applicationautoscaling']") -> "BackendDict[ApplicationAutoscalingBackend]": ...
+def get_backend(
+    name: "Literal['applicationautoscaling']",
+) -> "BackendDict[ApplicationAutoscalingBackend]": ...
 @overload
 def get_backend(name: "Literal['appsync']") -> "BackendDict[AppSyncBackend]": ...
 @overload
 def get_backend(name: "Literal['athena']") -> "BackendDict[AthenaBackend]": ...
 @overload
-def get_backend(name: "Literal['autoscaling']") -> "BackendDict[AutoScalingBackend]": ...
+def get_backend(
+    name: "Literal['autoscaling']",
+) -> "BackendDict[AutoScalingBackend]": ...
 @overload
 def get_backend(name: "Literal['batch']") -> "BackendDict[BatchBackend]": ...
 @overload
+def get_backend(name: "Literal['bedrock']") -> "BackendDict[BedrockBackend]": ...
+@overload
+def get_backend(
+    name: "Literal['bedrock-agent']",
+) -> "BackendDict[AgentsforBedrockBackend]": ...
+@overload
 def get_backend(name: "Literal['budgets']") -> "BackendDict[BudgetsBackend]": ...
 @overload
 def get_backend(name: "Literal['ce']") -> "BackendDict[CostExplorerBackend]": ...
 @overload
-def get_backend(name: "Literal['cloudformation']") -> "BackendDict[CloudFormationBackend]": ...
+def get_backend(
+    name: "Literal['cloudformation']",
+) -> "BackendDict[CloudFormationBackend]": ...
 @overload
 def get_backend(name: "Literal['cloudfront']") -> "BackendDict[CloudFrontBackend]": ...
 @overload
@@ -352,9 +372,13 @@ def get_backend(name: "Literal['codebuild']") -> "BackendDict[CodeBuildBackend]"
 @overload
 def get_backend(name: "Literal['codecommit']") -> "BackendDict[CodeCommitBackend]": ...
 @overload
-def get_backend(name: "Literal['codepipeline']") -> "BackendDict[CodePipelineBackend]": ...
+def get_backend(
+    name: "Literal['codepipeline']",
+) -> "BackendDict[CodePipelineBackend]": ...
 @overload
-def get_backend(name: "Literal['cognito-identity']") -> "BackendDict[CognitoIdentityBackend]": ...
+def get_backend(
+    name: "Literal['cognito-identity']",
+) -> "BackendDict[CognitoIdentityBackend]": ...
 @overload
 def get_backend(name: "Literal['cognito-idp']") -> "BackendDict[CognitoIdpBackend]": ...
 @overload
@@ -364,41 +388,57 @@ def get_backend(name: "Literal['config']") -> "BackendDict[ConfigBackend]": ...
 @overload
 def get_backend(name: "Literal['databrew']") -> "BackendDict[DataBrewBackend]": ...
 @overload
-def get_backend(name: "Literal['datapipeline']") -> "BackendDict[DataPipelineBackend]": ...
+def get_backend(
+    name: "Literal['datapipeline']",
+) -> "BackendDict[DataPipelineBackend]": ...
 @overload
 def get_backend(name: "Literal['datasync']") -> "BackendDict[DataSyncBackend]": ...
 @overload
 def get_backend(name: "Literal['dax']") -> "BackendDict[DAXBackend]": ...
 @overload
-def get_backend(name: "Literal['dms']") -> "BackendDict[DatabaseMigrationServiceBackend]": ...
+def get_backend(
+    name: "Literal['dms']",
+) -> "BackendDict[DatabaseMigrationServiceBackend]": ...
 @overload
 def get_backend(name: "Literal['ds']") -> "BackendDict[DirectoryServiceBackend]": ...
 @overload
 def get_backend(name: "Literal['dynamodb']") -> "BackendDict[DynamoDBBackend]": ...
 @overload
-def get_backend(name: "Literal['dynamodb_v20111205']") -> "BackendDict[DynamoDBBackend_v20111205]": ...
+def get_backend(
+    name: "Literal['dynamodb_v20111205']",
+) -> "BackendDict[DynamoDBBackend_v20111205]": ...
 @overload
-def get_backend(name: "Literal['dynamodbstreams']") -> "BackendDict[DynamoDBStreamsBackend]": ...
+def get_backend(
+    name: "Literal['dynamodbstreams']",
+) -> "BackendDict[DynamoDBStreamsBackend]": ...
 @overload
 def get_backend(name: "Literal['ebs']") -> "BackendDict[EBSBackend]": ...
 @overload
 def get_backend(name: "Literal['ec2']") -> "BackendDict[EC2Backend]": ...
 @overload
-def get_backend(name: "Literal['ec2instanceconnect']") -> "BackendDict[Ec2InstanceConnectBackend]": ...
+def get_backend(
+    name: "Literal['ec2instanceconnect']",
+) -> "BackendDict[Ec2InstanceConnectBackend]": ...
 @overload
 def get_backend(name: "Literal['ecr']") -> "BackendDict[ECRBackend]": ...
 @overload
-def get_backend(name: "Literal['ecs']") -> "BackendDict[EC2ContainerServiceBackend]": ...
+def get_backend(
+    name: "Literal['ecs']",
+) -> "BackendDict[EC2ContainerServiceBackend]": ...
 @overload
 def get_backend(name: "Literal['efs']") -> "BackendDict[EFSBackend]": ...
 @overload
 def get_backend(name: "Literal['eks']") -> "BackendDict[EKSBackend]": ...
 @overload
-def get_backend(name: "Literal['elasticache']") -> "BackendDict[ElastiCacheBackend]": ...
+def get_backend(
+    name: "Literal['elasticache']",
+) -> "BackendDict[ElastiCacheBackend]": ...
 @overload
 def get_backend(name: "Literal['elasticbeanstalk']") -> "BackendDict[EBBackend]": ...
 @overload
-def get_backend(name: "Literal['elastictranscoder']") -> "BackendDict[ElasticTranscoderBackend]": ...
+def get_backend(
+    name: "Literal['elastictranscoder']",
+) -> "BackendDict[ElasticTranscoderBackend]": ...
 @overload
 def get_backend(name: "Literal['elb']") -> "BackendDict[ELBBackend]": ...
 @overload
@@ -406,11 +446,17 @@ def get_backend(name: "Literal['elbv2']") -> "BackendDict[ELBv2Backend]": ...
 @overload
 def get_backend(name: "Literal['emr']") -> "BackendDict[ElasticMapReduceBackend]": ...
 @overload
-def get_backend(name: "Literal['emr-containers']") -> "BackendDict[EMRContainersBackend]": ...
+def get_backend(
+    name: "Literal['emr-containers']",
+) -> "BackendDict[EMRContainersBackend]": ...
 @overload
-def get_backend(name: "Literal['emr-serverless']") -> "BackendDict[EMRServerlessBackend]": ...
+def get_backend(
+    name: "Literal['emr-serverless']",
+) -> "BackendDict[EMRServerlessBackend]": ...
 @overload
-def get_backend(name: "Literal['es']") -> "BackendDict[ElasticsearchServiceBackend]": ...
+def get_backend(
+    name: "Literal['es']",
+) -> "BackendDict[ElasticsearchServiceBackend]": ...
 @overload
 def get_backend(name: "Literal['events']") -> "BackendDict[EventsBackend]": ...
 @overload
@@ -428,11 +474,15 @@ def get_backend(name: "Literal['guardduty']") -> "BackendDict[GuardDutyBackend]"
 @overload
 def get_backend(name: "Literal['iam']") -> "BackendDict[IAMBackend]": ...
 @overload
-def get_backend(name: "Literal['identitystore']") -> "BackendDict[IdentityStoreBackend]": ...
+def get_backend(
+    name: "Literal['identitystore']",
+) -> "BackendDict[IdentityStoreBackend]": ...
 @overload
 def get_backend(name: "Literal['inspector2']") -> "BackendDict[Inspector2Backend]": ...
 @overload
-def get_backend(name: "Literal['instance_metadata']") -> "BackendDict[InstanceMetadataBackend]": ...
+def get_backend(
+    name: "Literal['instance_metadata']",
+) -> "BackendDict[InstanceMetadataBackend]": ...
 @overload
 def get_backend(name: "Literal['iot']") -> "BackendDict[IoTBackend]": ...
 @overload
@@ -442,31 +492,47 @@ def get_backend(name: "Literal['ivs']") -> "BackendDict[IVSBackend]": ...
 @overload
 def get_backend(name: "Literal['kinesis']") -> "BackendDict[KinesisBackend]": ...
 @overload
-def get_backend(name: "Literal['kinesisvideo']") -> "BackendDict[KinesisVideoBackend]": ...
+def get_backend(
+    name: "Literal['kinesisvideo']",
+) -> "BackendDict[KinesisVideoBackend]": ...
 @overload
-def get_backend(name: "Literal['kinesis-video-archived-media']") -> "BackendDict[KinesisVideoArchivedMediaBackend]": ...
+def get_backend(
+    name: "Literal['kinesis-video-archived-media']",
+) -> "BackendDict[KinesisVideoArchivedMediaBackend]": ...
 @overload
 def get_backend(name: "Literal['kms']") -> "BackendDict[KmsBackend]": ...
 @overload
-def get_backend(name: "Literal['lakeformation']") -> "BackendDict[LakeFormationBackend]": ...
+def get_backend(
+    name: "Literal['lakeformation']",
+) -> "BackendDict[LakeFormationBackend]": ...
 @overload
 def get_backend(name: "Literal['lambda']") -> "BackendDict[LambdaBackend]": ...
 @overload
 def get_backend(name: "Literal['logs']") -> "BackendDict[LogsBackend]": ...
 @overload
-def get_backend(name: "Literal['managedblockchain']") -> "BackendDict[ManagedBlockchainBackend]": ...
+def get_backend(
+    name: "Literal['managedblockchain']",
+) -> "BackendDict[ManagedBlockchainBackend]": ...
 @overload
-def get_backend(name: "Literal['mediaconnect']") -> "BackendDict[MediaConnectBackend]": ...
+def get_backend(
+    name: "Literal['mediaconnect']",
+) -> "BackendDict[MediaConnectBackend]": ...
 @overload
 def get_backend(name: "Literal['medialive']") -> "BackendDict[MediaLiveBackend]": ...
 @overload
-def get_backend(name: "Literal['mediapackage']") -> "BackendDict[MediaPackageBackend]": ...
+def get_backend(
+    name: "Literal['mediapackage']",
+) -> "BackendDict[MediaPackageBackend]": ...
 @overload
 def get_backend(name: "Literal['mediastore']") -> "BackendDict[MediaStoreBackend]": ...
 @overload
-def get_backend(name: "Literal['mediastore-data']") -> "BackendDict[MediaStoreDataBackend]": ...
+def get_backend(
+    name: "Literal['mediastore-data']",
+) -> "BackendDict[MediaStoreDataBackend]": ...
 @overload
-def get_backend(name: "Literal['meteringmarketplace']") -> "BackendDict[MeteringMarketplaceBackend]": ...
+def get_backend(
+    name: "Literal['meteringmarketplace']",
+) -> "BackendDict[MeteringMarketplaceBackend]": ...
 @overload
 def get_backend(name: "Literal['moto_api']") -> "BackendDict[MotoAPIBackend]": ...
 @overload
@@ -474,13 +540,19 @@ def get_backend(name: "Literal['mq']") -> "BackendDict[MQBackend]": ...
 @overload
 def get_backend(name: "Literal['neptune']") -> "BackendDict[NeptuneBackend]": ...
 @overload
-def get_backend(name: "Literal['opensearch']") -> "BackendDict[OpenSearchServiceBackend]": ...
+def get_backend(
+    name: "Literal['opensearch']",
+) -> "BackendDict[OpenSearchServiceBackend]": ...
 @overload
 def get_backend(name: "Literal['opsworks']") -> "BackendDict[OpsWorksBackend]": ...
 @overload
-def get_backend(name: "Literal['organizations']") -> "BackendDict[OrganizationsBackend]": ...
+def get_backend(
+    name: "Literal['organizations']",
+) -> "BackendDict[OrganizationsBackend]": ...
 @overload
-def get_backend(name: "Literal['personalize']") -> "BackendDict[PersonalizeBackend]": ...
+def get_backend(
+    name: "Literal['personalize']",
+) -> "BackendDict[PersonalizeBackend]": ...
 @overload
 def get_backend(name: "Literal['pinpoint']") -> "BackendDict[PinpointBackend]": ...
 @overload
@@ -488,27 +560,49 @@ def get_backend(name: "Literal['polly']") -> "BackendDict[PollyBackend]": ...
 @overload
 def get_backend(name: "Literal['quicksight']") -> "BackendDict[QuickSightBackend]": ...
 @overload
-def get_backend(name: "Literal['ram']") -> "BackendDict[ResourceAccessManagerBackend]": ...
+def get_backend(
+    name: "Literal['ram']",
+) -> "BackendDict[ResourceAccessManagerBackend]": ...
 @overload
 def get_backend(name: "Literal['rds']") -> "BackendDict[RDSBackend]": ...
 @overload
-def get_backend(name: "Literal['rds-data']") -> "BackendDict[RDSDataServiceBackend]": ...
+def get_backend(
+    name: "Literal['rds-data']",
+) -> "BackendDict[RDSDataServiceBackend]": ...
 @overload
 def get_backend(name: "Literal['redshift']") -> "BackendDict[RedshiftBackend]": ...
 @overload
-def get_backend(name: "Literal['redshift-data']") -> "BackendDict[RedshiftDataAPIServiceBackend]": ...
+def get_backend(
+    name: "Literal['redshift-data']",
+) -> "BackendDict[RedshiftDataAPIServiceBackend]": ...
 @overload
-def get_backend(name: "Literal['rekognition']") -> "BackendDict[RekognitionBackend]": ...
+def get_backend(
+    name: "Literal['rekognition']",
+) -> "BackendDict[RekognitionBackend]": ...
 @overload
-def get_backend(name: "Literal['resource-groups']") -> "BackendDict[ResourceGroupsBackend]": ...
+def get_backend(
+    name: "Literal['resiliencehub']",
+) -> "BackendDict[ResilienceHubBackend]": ...
 @overload
-def get_backend(name: "Literal['resourcegroupstaggingapi']") -> "BackendDict[ResourceGroupsTaggingAPIBackend]": ...
+def get_backend(
+    name: "Literal['resource-groups']",
+) -> "BackendDict[ResourceGroupsBackend]": ...
+@overload
+def get_backend(
+    name: "Literal['resourcegroupstaggingapi']",
+) -> "BackendDict[ResourceGroupsTaggingAPIBackend]": ...
 @overload
 def get_backend(name: "Literal['robomaker']") -> "BackendDict[RoboMakerBackend]": ...
 @overload
 def get_backend(name: "Literal['route53']") -> "BackendDict[Route53Backend]": ...
 @overload
-def get_backend(name: "Literal['route53resolver']") -> "BackendDict[Route53ResolverBackend]": ...
+def get_backend(
+    name: "Literal['route53resolver']",
+) -> "BackendDict[Route53ResolverBackend]": ...
+@overload
+def get_backend(
+    name: "Literal['route53domains']",
+) -> "BackendDict[Route53DomainsBackend]": ...
 @overload
 def get_backend(name: "Literal['s3']") -> "BackendDict[S3Backend]": ...
 @overload
@@ -516,19 +610,31 @@ def get_backend(name: "Literal['s3bucket_path']") -> "BackendDict[S3Backend]": .
 @overload
 def get_backend(name: "Literal['s3control']") -> "BackendDict[S3ControlBackend]": ...
 @overload
-def get_backend(name: "Literal['sagemaker']") -> "BackendDict[SageMakerModelBackend]": ...
+def get_backend(
+    name: "Literal['sagemaker']",
+) -> "BackendDict[SageMakerModelBackend]": ...
 @overload
-def get_backend(name: "Literal['sagemaker-runtime']") -> "BackendDict[SageMakerRuntimeBackend]": ...
+def get_backend(
+    name: "Literal['sagemaker-runtime']",
+) -> "BackendDict[SageMakerRuntimeBackend]": ...
 @overload
-def get_backend(name: "Literal['scheduler']") -> "BackendDict[EventBridgeSchedulerBackend]": ...
+def get_backend(
+    name: "Literal['scheduler']",
+) -> "BackendDict[EventBridgeSchedulerBackend]": ...
 @overload
 def get_backend(name: "Literal['sdb']") -> "BackendDict[SimpleDBBackend]": ...
 @overload
-def get_backend(name: "Literal['secretsmanager']") -> "BackendDict[SecretsManagerBackend]": ...
+def get_backend(
+    name: "Literal['secretsmanager']",
+) -> "BackendDict[SecretsManagerBackend]": ...
 @overload
-def get_backend(name: "Literal['servicediscovery']") -> "BackendDict[ServiceDiscoveryBackend]": ...
+def get_backend(
+    name: "Literal['servicediscovery']",
+) -> "BackendDict[ServiceDiscoveryBackend]": ...
 @overload
-def get_backend(name: "Literal['service-quotas']") -> "BackendDict[ServiceQuotasBackend]": ...
+def get_backend(
+    name: "Literal['service-quotas']",
+) -> "BackendDict[ServiceQuotasBackend]": ...
 @overload
 def get_backend(name: "Literal['ses']") -> "BackendDict[SESBackend]": ...
 @overload
@@ -540,11 +646,15 @@ def get_backend(name: "Literal['sns']") -> "BackendDict[SNSBackend]": ...
 @overload
 def get_backend(name: "Literal['sqs']") -> "BackendDict[SQSBackend]": ...
 @overload
-def get_backend(name: "Literal['ssm']") -> "BackendDict[SimpleSystemManagerBackend]": ...
+def get_backend(
+    name: "Literal['ssm']",
+) -> "BackendDict[SimpleSystemManagerBackend]": ...
 @overload
 def get_backend(name: "Literal['sso-admin']") -> "BackendDict[SSOAdminBackend]": ...
 @overload
-def get_backend(name: "Literal['stepfunctions']") -> "BackendDict[StepFunctionBackend]": ...
+def get_backend(
+    name: "Literal['stepfunctions']",
+) -> "BackendDict[StepFunctionBackend]": ...
 @overload
 def get_backend(name: "Literal['sts']") -> "BackendDict[STSBackend]": ...
 @overload
@@ -554,16 +664,23 @@ def get_backend(name: "Literal['swf']") -> "BackendDict[SWFBackend]": ...
 @overload
 def get_backend(name: "Literal['textract']") -> "BackendDict[TextractBackend]": ...
 @overload
-def get_backend(name: "Literal['timestream-write']") -> "BackendDict[TimestreamWriteBackend]": ...
+def get_backend(
+    name: "Literal['timestream-write']",
+) -> "BackendDict[TimestreamWriteBackend]": ...
 @overload
 def get_backend(name: "Literal['transcribe']") -> "BackendDict[TranscribeBackend]": ...
 @overload
 def get_backend(name: "Literal['wafv2']") -> "BackendDict[WAFV2Backend]": ...
 @overload
+def get_backend(name: "Literal['workspaces']") -> "BackendDict[WorkSpacesBackend]": ...
+@overload
 def get_backend(name: "Literal['xray']") -> "BackendDict[XRayBackend]": ...
-# fmt: on
 
 
 def get_backend(name: SERVICE_NAMES) -> "BackendDict[SERVICE_BACKEND]":
-    module_name, backends_name = BACKENDS[name]
-    return _import_backend(module_name, backends_name)
+    # fmt: on
+    safe_name = name.replace("-", "")
+    return _import_backend(
+        ALT_SERVICE_NAMES.get(safe_name, safe_name),
+        f"{ALT_BACKEND_NAMES.get(safe_name, safe_name)}_backends",
+    )
