@@ -1,49 +1,61 @@
-import boto3
-import functools
 import datetime
+import functools
 import json
 import logging
 import os
 import re
+from collections import OrderedDict, defaultdict
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    ClassVar,
+    Dict,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    TypeVar,
+    Union,
+)
+from urllib.parse import parse_qs, parse_qsl, urlparse
+from xml.dom.minidom import parseString as parseXML
+
+import boto3
 import requests
 import xmltodict
+from jinja2 import DictLoader, Environment, Template
+from werkzeug.exceptions import HTTPException
 
-from collections import defaultdict, OrderedDict
 from moto import settings
-from moto.core.common_types import TYPE_RESPONSE, TYPE_IF_NONE
+from moto.core.common_types import TYPE_IF_NONE, TYPE_RESPONSE
 from moto.core.exceptions import DryRunClientError
 from moto.core.utils import (
     camelcase_to_underscores,
     gzip_decompress,
     method_names_from_class,
     params_sort_function,
+    utcfromtimestamp,
 )
-from moto.utilities.utils import load_resource
-from jinja2 import Environment, DictLoader, Template
-from typing import (
-    Dict,
-    Union,
-    Any,
-    Tuple,
-    Optional,
-    List,
-    Set,
-    ClassVar,
-    Callable,
-    TypeVar,
-)
-from urllib.parse import parse_qs, parse_qsl, urlparse
-from werkzeug.exceptions import HTTPException
-from xml.dom.minidom import parseString as parseXML
-
+from moto.utilities.aws_headers import gen_amzn_requestid_long
+from moto.utilities.utils import load_resource, load_resource_as_bytes
 
 log = logging.getLogger(__name__)
 
 JINJA_ENVS: Dict[type, Environment] = {}
 
+if TYPE_CHECKING:
+    from typing_extensions import ParamSpec
+
+    P = ParamSpec("P")
+
+T = TypeVar("T")
+
 
 ResponseShape = TypeVar("ResponseShape", bound="BaseResponse")
 
+boto3_service_name = {"awslambda": "lambda"}
+
 
 def _decode_dict(d: Dict[Any, Any]) -> Dict[str, Any]:
     decoded: Dict[str, Any] = OrderedDict()
@@ -133,6 +145,16 @@ class _TemplateEnvironmentMixin(object):
 class ActionAuthenticatorMixin(object):
     request_count: ClassVar[int] = 0
 
+    PUBLIC_OPERATIONS = [
+        "AWSCognitoIdentityService.GetId",
+        "AWSCognitoIdentityService.GetOpenIdToken",
+        "AWSCognitoIdentityProviderService.ConfirmSignUp",
+        "AWSCognitoIdentityProviderService.GetUser",
+        "AWSCognitoIdentityProviderService.ForgotPassword",
+        "AWSCognitoIdentityProviderService.InitiateAuth",
+        "AWSCognitoIdentityProviderService.SignUp",
+    ]
+
     def _authenticate_and_authorize_action(
         self, iam_request_cls: type, resource: str = "*"
     ) -> None:
@@ -140,6 +162,11 @@ class ActionAuthenticatorMixin(object):
             ActionAuthenticatorMixin.request_count
             >= settings.INITIAL_NO_AUTH_ACTION_COUNT
         ):
+            if (
+                self.headers.get("X-Amz-Target")  # type: ignore[attr-defined]
+                in ActionAuthenticatorMixin.PUBLIC_OPERATIONS
+            ):
+                return
             parsed_url = urlparse(self.uri)  # type: ignore[attr-defined]
             path = parsed_url.path
             if parsed_url.query:
@@ -149,6 +176,7 @@ class ActionAuthenticatorMixin(object):
                 method=self.method,  # type: ignore[attr-defined]
                 path=path,
                 data=self.data,  # type: ignore[attr-defined]
+                body=self.body,  # type: ignore[attr-defined]
                 headers=self.headers,  # type: ignore[attr-defined]
             )
             iam_request.check_signature()
@@ -156,10 +184,10 @@ class ActionAuthenticatorMixin(object):
         else:
             ActionAuthenticatorMixin.request_count += 1
 
-    def _authenticate_and_authorize_normal_action(self) -> None:
+    def _authenticate_and_authorize_normal_action(self, resource: str = "*") -> None:
         from moto.iam.access_control import IAMRequest
 
-        self._authenticate_and_authorize_action(IAMRequest)
+        self._authenticate_and_authorize_action(IAMRequest, resource)
 
     def _authenticate_and_authorize_s3_action(
         self, bucket_name: Optional[str] = None, key_name: Optional[str] = None
@@ -172,13 +200,13 @@ class ActionAuthenticatorMixin(object):
         self._authenticate_and_authorize_action(S3IAMRequest, resource)
 
     @staticmethod
-    def set_initial_no_auth_action_count(initial_no_auth_action_count: int) -> Callable[..., Callable[..., TYPE_RESPONSE]]:  # type: ignore[misc]
+    def set_initial_no_auth_action_count(
+        initial_no_auth_action_count: int,
+    ) -> "Callable[[Callable[P, T]], Callable[P, T]]":
         _test_server_mode_endpoint = settings.test_server_mode_endpoint()
 
-        def decorator(
-            function: Callable[..., TYPE_RESPONSE]
-        ) -> Callable[..., TYPE_RESPONSE]:
-            def wrapper(*args: Any, **kwargs: Any) -> TYPE_RESPONSE:
+        def decorator(function: "Callable[P, T]") -> "Callable[P, T]":
+            def wrapper(*args: "P.args", **kwargs: "P.kwargs") -> T:
                 if settings.TEST_SERVER_MODE:
                     response = requests.post(
                         f"{_test_server_mode_endpoint}/moto-api/reset-auth",
@@ -257,7 +285,15 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
 
         @functools.wraps(to_call)  # type: ignore
         def _inner(request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:
-            return getattr(cls(), to_call.__name__)(request, full_url, headers)
+            response = getattr(cls(), to_call.__name__)(request, full_url, headers)
+            if isinstance(response, str):
+                status = 200
+                body = response
+                headers = {}
+            else:
+                status, headers, body = response
+            headers, body = cls._enrich_response(headers, body)
+            return status, headers, body
 
         return _inner
 
@@ -281,11 +317,34 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
             # definition for back-compatibility
             self.body = request.data
 
-            querystring = OrderedDict()
+        if hasattr(request, "form"):
+            self.form_data = request.form
             for key, value in request.form.items():
                 querystring[key] = [value]
+        else:
+            self.form_data = {}
 
-        raw_body = self.body
+        if hasattr(request, "form") and "key" in request.form:
+            if "file" in request.form:
+                self.body = request.form["file"]
+            else:
+                # Body comes through as part of the form, if no content-type is set on the PUT-request
+                # form = ImmutableMultiDict([('some data 123 321', '')])
+                form = request.form
+                for k, _ in form.items():
+                    self.body = k
+        if hasattr(request, "files") and request.files:
+            for _, value in request.files.items():
+                self.body = value.stream.read()
+                value.stream.close()
+            if querystring.get("key"):
+                filename = os.path.basename(request.files["file"].filename)
+                querystring["key"] = [
+                    querystring["key"][0].replace("${filename}", filename)
+                ]
+
+        if hasattr(self.body, "read"):
+            self.body = self.body.read()
 
         # https://github.com/getmoto/moto/issues/6692
         # Content coming from SDK's can be GZipped for performance reasons
@@ -321,7 +380,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
                         OrderedDict(
                             (key, [value])
                             for key, value in parse_qsl(
-                                raw_body, keep_blank_values=True
+                                self.body, keep_blank_values=True
                             )
                         )
                     )
@@ -338,6 +397,13 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         self.uri = full_url
 
         self.path = self.parsed_url.path
+        if self.is_werkzeug_request and "RAW_URI" in request.environ:
+            self.raw_path = urlparse(request.environ.get("RAW_URI")).path
+            if self.raw_path and not self.raw_path.startswith("/"):
+                self.raw_path = f"/{self.raw_path}"
+        else:
+            self.raw_path = self.path
+
         self.querystring = querystring
         self.data = querystring
         self.method = request.method
@@ -427,7 +493,10 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
 
         def _convert(elem: str, is_last: bool) -> str:
             if not re.match("^{.*}$", elem):
-                return elem
+                # URL-parts sometimes contain a $
+                # Like Greengrass: /../deployments/$reset
+                # We don't want to our regex to think this marks an end-of-line, so let's escape it
+                return elem.replace("$", r"\$")
             name = (
                 elem.replace("{", "")
                 .replace("}", "")
@@ -453,9 +522,8 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         https://github.com/boto/botocore/blob/develop/botocore/data/iot/2015-05-28/service-2.json
         """
 
-        # service response class should have 'SERVICE_NAME' class member,
-        # if you want to get action from method and url
-        conn = boto3.client(self.service_name, region_name=self.region)
+        service_name = boto3_service_name.get(self.service_name) or self.service_name  # type: ignore
+        conn = boto3.client(service_name, region_name=self.region)
 
         # make cache if it does not exist yet
         if not hasattr(self, "method_urls"):
@@ -486,19 +554,27 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         if match:
             return match.split(".")[-1]
         # get action from method and uri
-        return self._get_action_from_method_and_request_uri(self.method, self.path)
+        return self._get_action_from_method_and_request_uri(self.method, self.raw_path)
 
     def call_action(self) -> TYPE_RESPONSE:
         headers = self.response_headers
+        if hasattr(self, "_determine_resource"):
+            resource = self._determine_resource()
+        else:
+            resource = "*"
 
         try:
-            self._authenticate_and_authorize_normal_action()
+            self._authenticate_and_authorize_normal_action(resource)
         except HTTPException as http_error:
             response = http_error.description, dict(status=http_error.code)
-            return self._send_response(headers, response)
+            status, headers, body = self._transform_response(headers, response)
+            headers, body = self._enrich_response(headers, body)
+
+            return status, headers, body
 
         action = camelcase_to_underscores(self._get_action())
         method_names = method_names_from_class(self.__class__)
+
         if action in method_names:
             method = getattr(self, action)
             try:
@@ -511,9 +587,14 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
                 response = http_error.description, response_headers  # type: ignore[assignment]
 
             if isinstance(response, str):
-                return 200, headers, response
+                status = 200
+                body = response
             else:
-                return self._send_response(headers, response)
+                status, headers, body = self._transform_response(headers, response)
+
+            headers, body = self._enrich_response(headers, body)
+
+            return status, headers, body
 
         if not action:
             return 404, headers, ""
@@ -521,19 +602,33 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         raise NotImplementedError(f"The {action} action has not been implemented")
 
     @staticmethod
-    def _send_response(headers: Dict[str, str], response: Any) -> Tuple[int, Dict[str, str], str]:  # type: ignore[misc]
+    def _transform_response(headers: Dict[str, str], response: Any) -> TYPE_RESPONSE:  # type: ignore[misc]
         if response is None:
             response = "", {}
         if len(response) == 2:
             body, new_headers = response
         else:
             status, new_headers, body = response
-        status = new_headers.get("status", 200)
+        status = int(new_headers.get("status", 200))
         headers.update(new_headers)
+        return status, headers, body
+
+    @staticmethod
+    def _enrich_response(  # type: ignore[misc]
+        headers: Dict[str, str], body: Any
+    ) -> Tuple[Dict[str, str], Any]:
         # Cast status to string
         if "status" in headers:
             headers["status"] = str(headers["status"])
-        return status, headers, body
+        # add request id
+        request_id = gen_amzn_requestid_long(headers)
+
+        # Update request ID in XML
+        try:
+            body = re.sub(r"(?<=<RequestId>).*(?=<\/RequestId>)", request_id, body)
+        except Exception:  # Will just ignore if it cant work
+            pass
+        return headers, body
 
     def _get_param(self, param_name: str, if_none: Any = None) -> Any:
         val = self.querystring.get(param_name)
@@ -544,9 +639,7 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         if self.body is not None:
             try:
                 return json.loads(self.body)[param_name]
-            except ValueError:
-                pass
-            except KeyError:
+            except (ValueError, KeyError):
                 pass
         # try to get path parameter
         if self.uri_match:
@@ -558,7 +651,9 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         return if_none
 
     def _get_int_param(
-        self, param_name: str, if_none: TYPE_IF_NONE = None  # type: ignore[assignment]
+        self,
+        param_name: str,
+        if_none: TYPE_IF_NONE = None,  # type: ignore[assignment]
     ) -> Union[int, TYPE_IF_NONE]:
         val = self._get_param(param_name)
         if val is not None:
@@ -566,7 +661,9 @@ class BaseResponse(_TemplateEnvironmentMixin, ActionAuthenticatorMixin):
         return if_none
 
     def _get_bool_param(
-        self, param_name: str, if_none: TYPE_IF_NONE = None  # type: ignore[assignment]
+        self,
+        param_name: str,
+        if_none: TYPE_IF_NONE = None,  # type: ignore[assignment]
     ) -> Union[bool, TYPE_IF_NONE]:
         val = self._get_param(param_name)
         if val is not None:
@@ -926,7 +1023,12 @@ class AWSServiceSpec(object):
     """
 
     def __init__(self, path: str):
-        spec = load_resource("botocore", path)
+        try:
+            spec = load_resource("botocore", path)
+        except FileNotFoundError:
+            # botocore >= 1.32.1 sends compressed files
+            compressed = load_resource_as_bytes("botocore", f"{path}.gz")
+            spec = json.loads(gzip_decompress(compressed).decode("utf-8"))
 
         self.metadata = spec["metadata"]
         self.operations = spec["operations"]
@@ -1028,11 +1130,7 @@ def to_str(value: Any, spec: Dict[str, Any]) -> str:
     elif vtype == "double":
         return str(value)
     elif vtype == "timestamp":
-        return (
-            datetime.datetime.utcfromtimestamp(value)
-            .replace(tzinfo=datetime.timezone.utc)
-            .isoformat()
-        )
+        return utcfromtimestamp(value).replace(tzinfo=datetime.timezone.utc).isoformat()
     elif vtype == "string":
         return str(value)
     elif value is None:
