@@ -1,10 +1,6 @@
 """FirehoseBackend class with methods for supported APIs.
 
 Incomplete list of unfinished items:
-  - The create_delivery_stream() argument
-    DeliveryStreamEncryptionConfigurationInput is not supported.
-  - The S3BackupMode argument is ignored as are most of the other
-    destination arguments.
   - Data record size and number of transactions are ignored.
   - Better validation of delivery destination parameters, e.g.,
     validation of the url for an http endpoint (boto3 does this).
@@ -15,18 +11,21 @@ Incomplete list of unfinished items:
     are reported back to the user.  Instead an exception is raised.
   - put_record(), put_record_batch() always set "Encrypted" to False.
 """
+
+import io
+import json
+import warnings
 from base64 import b64decode, b64encode
 from datetime import datetime, timezone
 from gzip import GzipFile
-import io
-import json
 from time import time
-import warnings
+from typing import Any, Dict, List, Optional, Tuple
 
 import requests
 
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
+from moto.core.utils import utcnow
 from moto.firehose.exceptions import (
     ConcurrentModificationException,
     InvalidArgumentException,
@@ -51,8 +50,8 @@ DESTINATION_TYPES_TO_NAMES = {
 }
 
 
-def find_destination_config_in_args(api_args):
-    """Return (config_arg, config_name) tuple for destination config.
+def find_destination_config_in_args(api_args: Dict[str, Any]) -> Tuple[str, Any]:
+    """Return (config_name, config) tuple for destination config.
 
     Determines which destination config(s) have been specified.  The
     alternative is to use a bunch of 'if' statements to check each
@@ -84,7 +83,9 @@ def find_destination_config_in_args(api_args):
     return configs[0]
 
 
-def create_s3_destination_config(extended_s3_destination_config):
+def create_s3_destination_config(
+    extended_s3_destination_config: Dict[str, Any],
+) -> Dict[str, Any]:
     """Return dict with selected fields copied from ExtendedS3 config.
 
     When an ExtendedS3 config is chosen, AWS tacks on a S3 config as
@@ -105,50 +106,58 @@ def create_s3_destination_config(extended_s3_destination_config):
     return destination
 
 
-class DeliveryStream(
-    BaseModel
-):  # pylint: disable=too-few-public-methods,too-many-instance-attributes
+class DeliveryStream(BaseModel):  # pylint: disable=too-few-public-methods,too-many-instance-attributes
     """Represents a delivery stream, its source and destination configs."""
 
     STATES = {"CREATING", "ACTIVE", "CREATING_FAILED"}
 
     MAX_STREAMS_PER_REGION = 50
 
+    ALTERNATIVE_FIELD_NAMES = [
+        ("S3Configuration", "S3DestinationDescription"),
+        ("S3Update", "S3DestinationDescription"),
+        ("S3BackupConfiguration", "S3BackupDescription"),
+        ("S3BackupUpdate", "S3BackupDescription"),
+    ]
+
     def __init__(
         self,
-        account_id,
-        region,
-        delivery_stream_name,
-        delivery_stream_type,
-        kinesis_stream_source_configuration,
-        destination_name,
-        destination_config,
+        account_id: str,
+        region: str,
+        delivery_stream_name: str,
+        delivery_stream_type: str,
+        encryption: Dict[str, Any],
+        kinesis_stream_source_configuration: Dict[str, Any],
+        destination_name: str,
+        destination_config: Dict[str, Any],
     ):  # pylint: disable=too-many-arguments
         self.delivery_stream_status = "CREATING"
         self.delivery_stream_name = delivery_stream_name
         self.delivery_stream_type = (
             delivery_stream_type if delivery_stream_type else "DirectPut"
         )
+        self.delivery_stream_encryption_configuration = encryption
 
         self.source = kinesis_stream_source_configuration
-        self.destinations = [
+        self.destinations: List[Dict[str, Any]] = [
             {
                 "destination_id": "destinationId-000000000001",
                 destination_name: destination_config,
             }
         ]
+
         if destination_name == "ExtendedS3":
             # Add a S3 destination as well, minus a few ExtendedS3 fields.
             self.destinations[0]["S3"] = create_s3_destination_config(
                 destination_config
             )
-        elif "S3Configuration" in destination_config:
-            # S3Configuration becomes S3DestinationDescription for the
-            # other destinations.
-            self.destinations[0][destination_name][
-                "S3DestinationDescription"
-            ] = destination_config["S3Configuration"]
-            del self.destinations[0][destination_name]["S3Configuration"]
+
+        # S3Configuration becomes S3DestinationDescription for the
+        # other destinations. Same for S3Backup
+        for old, new in DeliveryStream.ALTERNATIVE_FIELD_NAMES:
+            if old in destination_config:
+                self.destinations[0][destination_name][new] = destination_config[old]
+                del self.destinations[0][destination_name][old]
 
         self.delivery_stream_status = "ACTIVE"
         self.delivery_stream_arn = f"arn:aws:firehose:{region}:{account_id}:deliverystream/{delivery_stream_name}"
@@ -163,33 +172,35 @@ class DeliveryStream(
 class FirehoseBackend(BaseBackend):
     """Implementation of Firehose APIs."""
 
-    def __init__(self, region_name, account_id):
+    def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.delivery_streams = {}
+        self.delivery_streams: Dict[str, DeliveryStream] = {}
         self.tagger = TaggingService()
 
     @staticmethod
-    def default_vpc_endpoint_service(service_region, zones):
+    def default_vpc_endpoint_service(
+        service_region: str, zones: List[str]
+    ) -> List[Dict[str, str]]:
         """Default VPC endpoint service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "firehose", special_service_name="kinesis-firehose"
         )
 
-    def create_delivery_stream(
+    def create_delivery_stream(  # pylint: disable=unused-argument
         self,
-        region,
-        delivery_stream_name,
-        delivery_stream_type,
-        kinesis_stream_source_configuration,
-        delivery_stream_encryption_configuration_input,
-        s3_destination_configuration,
-        extended_s3_destination_configuration,
-        redshift_destination_configuration,
-        elasticsearch_destination_configuration,
-        splunk_destination_configuration,
-        http_endpoint_destination_configuration,
-        tags,
-    ):  # pylint: disable=too-many-arguments,too-many-locals,unused-argument
+        region: str,
+        delivery_stream_name: str,
+        delivery_stream_type: str,
+        kinesis_stream_source_configuration: Dict[str, Any],
+        delivery_stream_encryption_configuration_input: Dict[str, Any],
+        s3_destination_configuration: Dict[str, Any],
+        extended_s3_destination_configuration: Dict[str, Any],
+        redshift_destination_configuration: Dict[str, Any],
+        elasticsearch_destination_configuration: Dict[str, Any],
+        splunk_destination_configuration: Dict[str, Any],
+        http_endpoint_destination_configuration: Dict[str, Any],
+        tags: List[Dict[str, str]],
+    ) -> str:
         """Create a Kinesis Data Firehose delivery stream."""
         (destination_name, destination_config) = find_destination_config_in_args(
             locals()
@@ -209,12 +220,6 @@ class FirehoseBackend(BaseBackend):
             )
 
         # Rule out situations that are not yet implemented.
-        if delivery_stream_encryption_configuration_input:
-            warnings.warn(
-                "A delivery stream with server-side encryption enabled is not "
-                "yet implemented"
-            )
-
         if destination_name == "Splunk":
             warnings.warn("A Splunk destination delivery stream is not yet implemented")
 
@@ -243,22 +248,21 @@ class FirehoseBackend(BaseBackend):
         # by delivery stream name.  This instance will update the state and
         # create the ARN.
         delivery_stream = DeliveryStream(
-            self.account_id,
-            region,
-            delivery_stream_name,
-            delivery_stream_type,
-            kinesis_stream_source_configuration,
-            destination_name,
-            destination_config,
+            account_id=self.account_id,
+            region=region,
+            delivery_stream_name=delivery_stream_name,
+            delivery_stream_type=delivery_stream_type,
+            encryption=delivery_stream_encryption_configuration_input,
+            kinesis_stream_source_configuration=kinesis_stream_source_configuration,
+            destination_name=destination_name,
+            destination_config=destination_config,
         )
         self.tagger.tag_resource(delivery_stream.delivery_stream_arn, tags or [])
 
         self.delivery_streams[delivery_stream_name] = delivery_stream
         return self.delivery_streams[delivery_stream_name].delivery_stream_arn
 
-    def delete_delivery_stream(
-        self, delivery_stream_name, allow_force_delete=False
-    ):  # pylint: disable=unused-argument
+    def delete_delivery_stream(self, delivery_stream_name: str) -> None:
         """Delete a delivery stream and its data.
 
         AllowForceDelete option is ignored as we only superficially
@@ -276,9 +280,7 @@ class FirehoseBackend(BaseBackend):
         delivery_stream.delivery_stream_status = "DELETING"
         self.delivery_streams.pop(delivery_stream_name)
 
-    def describe_delivery_stream(
-        self, delivery_stream_name, limit, exclusive_start_destination_id
-    ):  # pylint: disable=unused-argument
+    def describe_delivery_stream(self, delivery_stream_name: str) -> Dict[str, Any]:
         """Return description of specified delivery stream and its status.
 
         Note:  the 'limit' and 'exclusive_start_destination_id' parameters
@@ -291,7 +293,9 @@ class FirehoseBackend(BaseBackend):
                 f"not found."
             )
 
-        result = {"DeliveryStreamDescription": {"HasMoreDestinations": False}}
+        result: Dict[str, Any] = {
+            "DeliveryStreamDescription": {"HasMoreDestinations": False}
+        }
         for attribute, attribute_value in vars(delivery_stream).items():
             if not attribute_value:
                 continue
@@ -327,8 +331,11 @@ class FirehoseBackend(BaseBackend):
         return result
 
     def list_delivery_streams(
-        self, limit, delivery_stream_type, exclusive_start_delivery_stream_name
-    ):
+        self,
+        limit: Optional[int],
+        delivery_stream_type: str,
+        exclusive_start_delivery_stream_name: str,
+    ) -> Dict[str, Any]:
         """Return list of delivery streams in alphabetic order of names."""
         result = {"DeliveryStreamNames": [], "HasMoreDeliveryStreams": False}
         if not self.delivery_streams:
@@ -336,7 +343,7 @@ class FirehoseBackend(BaseBackend):
 
         # If delivery_stream_type is specified, filter out any stream that's
         # not of that type.
-        stream_list = self.delivery_streams.keys()
+        stream_list = list(self.delivery_streams.keys())
         if delivery_stream_type:
             stream_list = [
                 x
@@ -364,8 +371,11 @@ class FirehoseBackend(BaseBackend):
         return result
 
     def list_tags_for_delivery_stream(
-        self, delivery_stream_name, exclusive_start_tag_key, limit
-    ):
+        self,
+        delivery_stream_name: str,
+        exclusive_start_tag_key: str,
+        limit: Optional[int],
+    ) -> Dict[str, Any]:
         """Return list of tags."""
         result = {"Tags": [], "HasMoreTags": False}
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
@@ -392,7 +402,9 @@ class FirehoseBackend(BaseBackend):
             result["HasMoreTags"] = True
         return result
 
-    def put_record(self, delivery_stream_name, record):
+    def put_record(
+        self, delivery_stream_name: str, record: Dict[str, bytes]
+    ) -> Dict[str, Any]:
         """Write a single data record into a Kinesis Data firehose stream."""
         result = self.put_record_batch(delivery_stream_name, [record])
         return {
@@ -401,7 +413,9 @@ class FirehoseBackend(BaseBackend):
         }
 
     @staticmethod
-    def put_http_records(http_destination, records):
+    def put_http_records(  # type: ignore[misc]
+        http_destination: Dict[str, Any], records: List[Dict[str, bytes]]
+    ) -> List[Dict[str, str]]:
         """Put records to a HTTP destination."""
         # Mostly copied from localstack
         url = http_destination["EndpointConfiguration"]["Url"]
@@ -421,7 +435,9 @@ class FirehoseBackend(BaseBackend):
         return [{"RecordId": str(mock_random.uuid4())} for _ in range(len(records))]
 
     @staticmethod
-    def _format_s3_object_path(delivery_stream_name, version_id, prefix):
+    def _format_s3_object_path(
+        delivery_stream_name: str, version_id: str, prefix: str
+    ) -> str:
         """Return a S3 object path in the expected format."""
         # Taken from LocalStack's firehose logic, with minor changes.
         # See https://docs.aws.amazon.com/firehose/latest/dev/basic-deliver.html#s3-object-name
@@ -429,14 +445,20 @@ class FirehoseBackend(BaseBackend):
         # Object name pattern:
         # DeliveryStreamName-DeliveryStreamVersion-YYYY-MM-DD-HH-MM-SS-RandomString
         prefix = f"{prefix}{'' if prefix.endswith('/') else '/'}"
-        now = datetime.utcnow()
+        now = utcnow()
         return (
             f"{prefix}{now.strftime('%Y/%m/%d/%H')}/"
             f"{delivery_stream_name}-{version_id}-"
             f"{now.strftime('%Y-%m-%d-%H-%M-%S')}-{str(mock_random.uuid4())}"
         )
 
-    def put_s3_records(self, delivery_stream_name, version_id, s3_destination, records):
+    def put_s3_records(
+        self,
+        delivery_stream_name: str,
+        version_id: str,
+        s3_destination: Dict[str, Any],
+        records: List[Dict[str, bytes]],
+    ) -> List[Dict[str, str]]:
         """Put records to a ExtendedS3 or S3 destination."""
         # Taken from LocalStack's firehose logic, with minor changes.
         bucket_name = s3_destination["BucketARN"].split(":")[-1]
@@ -457,7 +479,9 @@ class FirehoseBackend(BaseBackend):
             ) from exc
         return [{"RecordId": str(mock_random.uuid4())} for _ in range(len(records))]
 
-    def put_record_batch(self, delivery_stream_name, records):
+    def put_record_batch(
+        self, delivery_stream_name: str, records: List[Dict[str, bytes]]
+    ) -> Dict[str, Any]:
         """Write multiple data records into a Kinesis Data firehose stream."""
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
         if not delivery_stream:
@@ -503,7 +527,9 @@ class FirehoseBackend(BaseBackend):
             "RequestResponses": request_responses,
         }
 
-    def tag_delivery_stream(self, delivery_stream_name, tags):
+    def tag_delivery_stream(
+        self, delivery_stream_name: str, tags: List[Dict[str, str]]
+    ) -> None:
         """Add/update tags for specified delivery stream."""
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
         if not delivery_stream:
@@ -525,7 +551,9 @@ class FirehoseBackend(BaseBackend):
 
         self.tagger.tag_resource(delivery_stream.delivery_stream_arn, tags)
 
-    def untag_delivery_stream(self, delivery_stream_name, tag_keys):
+    def untag_delivery_stream(
+        self, delivery_stream_name: str, tag_keys: List[str]
+    ) -> None:
         """Removes tags from specified delivery stream."""
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
         if not delivery_stream:
@@ -538,23 +566,41 @@ class FirehoseBackend(BaseBackend):
             delivery_stream.delivery_stream_arn, tag_keys
         )
 
-    def update_destination(
+    def start_delivery_stream_encryption(
+        self, stream_name: str, encryption_config: Dict[str, Any]
+    ) -> None:
+        delivery_stream = self.delivery_streams.get(stream_name)
+        if not delivery_stream:
+            raise ResourceNotFoundException(
+                f"Firehose {stream_name} under account {self.account_id} not found."
+            )
+
+        delivery_stream.delivery_stream_encryption_configuration = encryption_config
+        delivery_stream.delivery_stream_encryption_configuration["Status"] = "ENABLED"
+
+    def stop_delivery_stream_encryption(self, stream_name: str) -> None:
+        delivery_stream = self.delivery_streams.get(stream_name)
+        if not delivery_stream:
+            raise ResourceNotFoundException(
+                f"Firehose {stream_name} under account {self.account_id} not found."
+            )
+
+        delivery_stream.delivery_stream_encryption_configuration["Status"] = "DISABLED"
+
+    def update_destination(  # pylint: disable=unused-argument
         self,
-        delivery_stream_name,
-        current_delivery_stream_version_id,
-        destination_id,
-        s3_destination_update,
-        extended_s3_destination_update,
-        s3_backup_mode,
-        redshift_destination_update,
-        elasticsearch_destination_update,
-        splunk_destination_update,
-        http_endpoint_destination_update,
-    ):  # pylint: disable=unused-argument,too-many-arguments,too-many-locals
-        """Updates specified destination of specified delivery stream."""
-        (destination_name, destination_config) = find_destination_config_in_args(
-            locals()
-        )
+        delivery_stream_name: str,
+        current_delivery_stream_version_id: str,
+        destination_id: str,
+        s3_destination_update: Dict[str, Any],
+        extended_s3_destination_update: Dict[str, Any],
+        s3_backup_mode: str,
+        redshift_destination_update: Dict[str, Any],
+        elasticsearch_destination_update: Dict[str, Any],
+        splunk_destination_update: Dict[str, Any],
+        http_endpoint_destination_update: Dict[str, Any],
+    ) -> None:
+        (dest_name, dest_config) = find_destination_config_in_args(locals())
 
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
         if not delivery_stream:
@@ -562,7 +608,7 @@ class FirehoseBackend(BaseBackend):
                 f"Firehose {delivery_stream_name} under accountId {self.account_id} not found."
             )
 
-        if destination_name == "Splunk":
+        if dest_name == "Splunk":
             warnings.warn("A Splunk destination delivery stream is not yet implemented")
 
         if delivery_stream.version_id != current_delivery_stream_version_id:
@@ -585,35 +631,42 @@ class FirehoseBackend(BaseBackend):
         # Switching between Amazon ES and other services is not supported.
         # For an Amazon ES destination, you can only update to another Amazon
         # ES destination.  Same with HTTP.  Didn't test Splunk.
-        if (
-            destination_name == "Elasticsearch" and "Elasticsearch" not in destination
-        ) or (destination_name == "HttpEndpoint" and "HttpEndpoint" not in destination):
+        if (dest_name == "Elasticsearch" and "Elasticsearch" not in destination) or (
+            dest_name == "HttpEndpoint" and "HttpEndpoint" not in destination
+        ):
             raise InvalidArgumentException(
-                f"Changing the destination type to or from {destination_name} "
+                f"Changing the destination type to or from {dest_name} "
                 f"is not supported at this time."
             )
 
         # If this is a different type of destination configuration,
         # the existing configuration is reset first.
-        if destination_name in destination:
-            delivery_stream.destinations[destination_idx][destination_name].update(
-                destination_config
-            )
+        if dest_name in destination:
+            delivery_stream.destinations[destination_idx][dest_name].update(dest_config)
         else:
             delivery_stream.destinations[destination_idx] = {
                 "destination_id": destination_id,
-                destination_name: destination_config,
+                dest_name: dest_config,
             }
 
+        # Some names in the Update-request differ from the names used by Describe
+        for old, new in DeliveryStream.ALTERNATIVE_FIELD_NAMES:
+            if old in dest_config:
+                if new not in delivery_stream.destinations[destination_idx][dest_name]:
+                    delivery_stream.destinations[destination_idx][dest_name][new] = {}
+                delivery_stream.destinations[destination_idx][dest_name][new].update(
+                    dest_config[old]
+                )
+
         # Once S3 is updated to an ExtendedS3 destination, both remain in
         # the destination.  That means when one is updated, the other needs
         # to be updated as well.  The problem is that they don't have the
         # same fields.
-        if destination_name == "ExtendedS3":
-            delivery_stream.destinations[destination_idx][
-                "S3"
-            ] = create_s3_destination_config(destination_config)
-        elif destination_name == "S3" and "ExtendedS3" in destination:
+        if dest_name == "ExtendedS3":
+            delivery_stream.destinations[destination_idx]["S3"] = (
+                create_s3_destination_config(dest_config)
+            )
+        elif dest_name == "S3" and "ExtendedS3" in destination:
             destination["ExtendedS3"] = {
                 k: v
                 for k, v in destination["S3"].items()
@@ -629,18 +682,18 @@ class FirehoseBackend(BaseBackend):
         # S3 backup if it is disabled.  If backup is enabled, you can't update
         # the delivery stream to disable it."
 
-    def lookup_name_from_arn(self, arn):
+    def lookup_name_from_arn(self, arn: str) -> Optional[DeliveryStream]:
         """Given an ARN, return the associated delivery stream name."""
         return self.delivery_streams.get(arn.split("/")[-1])
 
     def send_log_event(
         self,
-        delivery_stream_arn,
-        filter_name,
-        log_group_name,
-        log_stream_name,
-        log_events,
-    ):  # pylint:  disable=too-many-arguments
+        delivery_stream_arn: str,
+        filter_name: str,
+        log_group_name: str,
+        log_stream_name: str,
+        log_events: List[Dict[str, Any]],
+    ) -> None:
         """Send log events to a S3 bucket after encoding and gzipping it."""
         data = {
             "logEvents": log_events,
@@ -654,9 +707,9 @@ class FirehoseBackend(BaseBackend):
         output = io.BytesIO()
         with GzipFile(fileobj=output, mode="w") as fhandle:
             fhandle.write(json.dumps(data, separators=(",", ":")).encode("utf-8"))
-        gzipped_payload = b64encode(output.getvalue()).decode("utf-8")
+        gzipped_payload = b64encode(output.getvalue())
 
-        delivery_stream = self.lookup_name_from_arn(delivery_stream_arn)
+        delivery_stream: DeliveryStream = self.lookup_name_from_arn(delivery_stream_arn)  # type: ignore[assignment]
         self.put_s3_records(
             delivery_stream.delivery_stream_name,
             delivery_stream.version_id,
