@@ -1,12 +1,17 @@
 import datetime
 import re
 from base64 import b64decode
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, List, Optional, Tuple
 
 import xmltodict
 
-from moto.core import BackendDict, BaseBackend, BaseModel
-from moto.core.utils import iso_8601_datetime_with_milliseconds, utcnow
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
+from moto.core.utils import (
+    get_partition_from_region,
+    iso_8601_datetime_with_milliseconds,
+    utcnow,
+)
 from moto.iam.models import AccessKey, iam_backends
 from moto.sts.utils import (
     DEFAULT_STS_SESSION_DURATION,
@@ -31,6 +36,7 @@ class AssumedRole(BaseModel):
     def __init__(
         self,
         account_id: str,
+        region_name: str,
         access_key: AccessKey,
         role_session_name: str,
         role_arn: str,
@@ -39,6 +45,7 @@ class AssumedRole(BaseModel):
         external_id: str,
     ):
         self.account_id = account_id
+        self.region_name = region_name
         self.session_name = role_session_name
         self.role_arn = role_arn
         self.policy = policy
@@ -65,7 +72,8 @@ class AssumedRole(BaseModel):
 
     @property
     def arn(self) -> str:
-        return f"arn:aws:sts::{self.account_id}:assumed-role/{self.role_arn.split('/')[-1]}/{self.session_name}"
+        partition = get_partition_from_region(self.region_name)
+        return f"arn:{partition}:sts::{self.account_id}:assumed-role/{self.role_arn.split('/')[-1]}/{self.session_name}"
 
 
 class STSBackend(BaseBackend):
@@ -73,15 +81,6 @@ class STSBackend(BaseBackend):
         super().__init__(region_name, account_id)
         self.assumed_roles: List[AssumedRole] = []
 
-    @staticmethod
-    def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
-        """Default VPC endpoint service."""
-        return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "sts"
-        )
-
     def get_session_token(self, duration: int) -> Token:
         return Token(duration=duration)
 
@@ -90,6 +89,7 @@ class STSBackend(BaseBackend):
 
     def assume_role(
         self,
+        region_name: str,
         role_session_name: str,
         role_arn: str,
         policy: str,
@@ -101,13 +101,14 @@ class STSBackend(BaseBackend):
         """
         account_id, access_key = self._create_access_key(role=role_arn)
         role = AssumedRole(
-            account_id,
-            access_key,
-            role_session_name,
-            role_arn,
-            policy,
-            duration,
-            external_id,
+            account_id=account_id,
+            region_name=region_name,
+            access_key=access_key,
+            role_session_name=role_session_name,
+            role_arn=role_arn,
+            policy=policy,
+            duration=duration,
+            external_id=external_id,
         )
         access_key.role_arn = role_arn
         account_backend = sts_backends[account_id]["global"]
@@ -165,6 +166,7 @@ class STSBackend(BaseBackend):
 
         account_id, access_key = self._create_access_key(role=target_role)  # type: ignore
         kwargs["account_id"] = account_id
+        kwargs["region_name"] = self.region_name
         kwargs["access_key"] = access_key
 
         kwargs["external_id"] = None
@@ -173,7 +175,9 @@ class STSBackend(BaseBackend):
         self.assumed_roles.append(role)
         return role
 
-    def get_caller_identity(self, access_key_id: str) -> Tuple[str, str, str]:
+    def get_caller_identity(
+        self, access_key_id: str, region: str
+    ) -> Tuple[str, str, str]:
         assumed_role = self.get_assumed_role_from_access_key(access_key_id)
         if assumed_role:
             return assumed_role.user_id, assumed_role.arn, assumed_role.account_id
@@ -184,8 +188,9 @@ class STSBackend(BaseBackend):
             return user.id, user.arn, user.account_id
 
         # Default values in case the request does not use valid credentials generated by moto
+        partition = get_partition_from_region(region)
         user_id = "AKIAIOSFODNN7EXAMPLE"
-        arn = f"arn:aws:sts::{self.account_id}:user/moto"
+        arn = f"arn:{partition}:sts::{self.account_id}:user/moto"
         return user_id, arn, self.account_id
 
     def _create_access_key(self, role: str) -> Tuple[str, AccessKey]:
